---
name: Bug report
about: Something not working as described? Missing/incorrect documentation? This is the place.
title: ''
labels: 'bug'
assignees: ''

---
## Summary
<!--What is the nature of the bug?-->

## Additional details
<!--Please fill in the following details-->
- CuBIDS version:
- Datalad version:

### What were you trying to do?

### What did you expect to happen?

### What actually happened?

## Reproducing the bug
<!--Please share any steps you performed that revealed the bug-->
<!--Please include any code snippets.
Enclose them in triple back-ticks (```)
Like this:

```
<code>
```
-->
